@@ -3,7 +3,7 @@ package Getopt::EX::Config;
 use v5.14;
 use warnings;
 
-our $VERSION = '1.02';
+our $VERSION = '1.0201';
 
 our $REPLACE_UNDERSCORE = 1;
 
@@ -75,6 +75,9 @@ sub getopt {
     my $argv = shift // [];
     return if @{ $argv } == 0;
 
+    # Filter out internal keys (must start with a letter)
+    @_ = grep { ref($_) || /^[a-zA-Z]/ } @_;
+
     # Convert underscore options to underscore|dash format
     @_ = map { ref($_) ? $_ : s/^(\w*_[\w_]*)/"$1|" . ($1 =~ s:_:-:gr)/er } @_
         if $REPLACE_UNDERSCORE;
@@ -168,7 +171,7 @@ Getopt::EX::Config - Getopt::EX module configuration interface
 
 =head1 VERSION
 
-Version 1.02
+Version 1.0201
 
 =head1 DESCRIPTION
 
